==> meshagent_cli-0.0.29.tar.gz: meshagent_cli-0.0.29/meshagent/cli/voicebot.py <==

import typer
from rich import print
from typing import Annotated, Optional
import json
import aiohttp
from meshagent.api import RoomClient, ParticipantToken, WebSocketClientProtocol, RoomException
from meshagent.api.helpers import meshagent_base_url, websocket_room_url
from meshagent.api.services import send_webhook
from meshagent.cli import async_typer
from meshagent.cli.helper import get_client, print_json_table, set_active_project, resolve_project_id
from meshagent.cli.helper import set_active_project, get_active_project, resolve_project_id, resolve_api_key
from meshagent.openai import OpenAIResponsesAdapter
from typing import List

from meshagent.api import RequiredToolkit, RequiredSchema


try:

    from meshagent.livekit.agents.voice import VoiceBot

except ImportError:
    
    class VoiceBot:
        def __init__(**kwargs):
            raise RoomException("meshagent.livekit module not found, voicebots are not available")



app = async_typer.AsyncTyper()

@app.async_command("join")
async def make_call(
    *,
    project_id: str = None,
    room: Annotated[str, typer.Option()],
    api_key_id: Annotated[Optional[str], typer.Option()] = None,
    name: Annotated[str, typer.Option(..., help="Participant name")] = "cli",
    role: str = "agent",
    agent_name: Annotated[str, typer.Option(..., help="Name of the agent to call")],
    rule: Annotated[List[str], typer.Option("--rule", "-r", help="a system rule")] = [],
    toolkit: Annotated[List[str], typer.Option("--toolkit", "-t", help="the name or url of a required toolkit")] = [],
    schema: Annotated[List[str], typer.Option("--schema", "-s", help="the name or url of a required schema")] = [],
    greeting: Annotated[Optional[str], typer.Option()] = None,
):
    account_client = await get_client()
    try:
        project_id = await resolve_project_id(project_id=project_id)
        api_key_id = await resolve_api_key(project_id, api_key_id)
        
        key = (await account_client.decrypt_project_api_key(project_id=project_id, id=api_key_id))["token"]

        token = ParticipantToken(
            name=name,
            project_id=project_id,
            api_key_id=api_key_id
        )
        token.add_role_grant(role=role)
        token.add_room_grant(room)

        
        print("[bold green]Connecting to room...[/bold green]")
        async with RoomClient(
            protocol=WebSocketClientProtocol(url=websocket_room_url(room_name=room, base_url=meshagent_base_url()),
                                            token=token.to_jwt(token=key))
        ) as client:
            
            requirements = []

            for t in toolkit:
                requirements.append(RequiredToolkit(name=t))
            
            for t in schema:
                requirements.append(RequiredSchema(name=t))

            bot = VoiceBot(
                greeting=greeting,
                name=agent_name,
                requires=requirements,
                rules=rule if len(rule) > 0 else None
            )

            await bot.start(room=client)

            try:
                await client.protocol.wait_for_close()
            except KeyboardInterrupt:
                await bot.stop()
        
    finally:
        await account_client.close()

==> meshagent_cli-0.0.34.tar.gz: meshagent_cli-0.0.34/meshagent/cli/voicebot.py <==

import typer
from rich import print
from typing import Annotated, Optional
import json
import aiohttp
from meshagent.api import RoomClient, ParticipantToken, WebSocketClientProtocol, RoomException
from meshagent.api.helpers import meshagent_base_url, websocket_room_url
from meshagent.api.services import send_webhook
from meshagent.cli import async_typer
from meshagent.cli.helper import get_client, resolve_project_id, resolve_api_key, resolve_token_jwt, resolve_room
from meshagent.openai import OpenAIResponsesAdapter
from typing import List

from meshagent.api import RequiredToolkit, RequiredSchema
from meshagent.api.services import ServiceHost

try:

    from meshagent.livekit.agents.voice import VoiceBot

except ImportError:
    
    class VoiceBot:
        def __init__(**kwargs):
            raise RoomException("meshagent.livekit module not found, voicebots are not available")



app = async_typer.AsyncTyper()

@app.async_command("join")
async def make_call(
    *,
    project_id: str = None,
    room: Annotated[Optional[str], typer.Option()] = None,
    api_key_id: Annotated[Optional[str], typer.Option()] = None,
    name: Annotated[str, typer.Option(..., help="Participant name")] = "cli",
    role: str = "agent",
    agent_name: Annotated[str, typer.Option(..., help="Name of the agent to call")],
    rule: Annotated[List[str], typer.Option("--rule", "-r", help="a system rule")] = [],
    toolkit: Annotated[List[str], typer.Option("--toolkit", "-t", help="the name or url of a required toolkit")] = [],
    schema: Annotated[List[str], typer.Option("--schema", "-s", help="the name or url of a required schema")] = [],
    auto_greet_message: Annotated[Optional[str], typer.Option()] = None,
    auto_greet_prompt: Annotated[Optional[str], typer.Option()] = None,
    token_path: Annotated[Optional[str], typer.Option()] = None, 
):
    account_client = await get_client()
    try:
        project_id = await resolve_project_id(project_id=project_id)
        api_key_id = await resolve_api_key(project_id, api_key_id)
        
        room = resolve_room(room)
        jwt = await resolve_token_jwt(project_id=project_id, api_key_id=api_key_id, token_path=token_path, name=name, role=role, room=room)
        
        print("[bold green]Connecting to room...[/bold green]")
        async with RoomClient(
            protocol=WebSocketClientProtocol(url=websocket_room_url(room_name=room, base_url=meshagent_base_url()), token=jwt)
        ) as client:
            
            requirements = []

            for t in toolkit:
                requirements.append(RequiredToolkit(name=t))
            
            for t in schema:
                requirements.append(RequiredSchema(name=t))

            bot = VoiceBot(
                auto_greet_message=auto_greet_message,
                auto_greet_prompt=auto_greet_prompt,
                name=agent_name,
                requires=requirements,
                rules=rule if len(rule) > 0 else None
            )

            await bot.start(room=client)

            try:
                await client.protocol.wait_for_close()
            except KeyboardInterrupt:
                await bot.stop()
        
    finally:
        await account_client.close()


@app.async_command("service")
async def service(
    *,
    project_id: str = None,
    agent_name: Annotated[str, typer.Option(..., help="Name of the agent to call")],
    rule: Annotated[List[str], typer.Option("--rule", "-r", help="a system rule")] = [],
    toolkit: Annotated[List[str], typer.Option("--toolkit", "-t", help="the name or url of a required toolkit")] = [],
    schema: Annotated[List[str], typer.Option("--schema", "-s", help="the name or url of a required schema")] = [],
    auto_greet_message: Annotated[Optional[str], typer.Option()] = None,
    auto_greet_prompt: Annotated[Optional[str], typer.Option()] = None,

    host: Annotated[Optional[str], typer.Option()] = None, 
    port: Annotated[Optional[int], typer.Option()] = None, 
    path: Annotated[str, typer.Option()] = "/agent",
):
    requirements = []

    for t in toolkit:
        requirements.append(RequiredToolkit(name=t))
    
    for t in schema:
        requirements.append(RequiredSchema(name=t))

    service = ServiceHost(
        host=host,
        port=port
    )

    @service.path(path=path)
    class CustomVoiceBot(VoiceBot):
        def __init__(self):
            super().__init__(
                auto_greet_message=auto_greet_message,
                auto_greet_prompt=auto_greet_prompt,
                name=agent_name,
                requires=requirements,
                rules=rule if len(rule) > 0 else None
            )

    await service.run()
